@@ -22,9 +22,9 @@
 #include <KCalendarCore/Attendee>
 #include <KCalendarCore/ICalFormat>
 
+#include <KIdentityManagement/IdentityManager>
 #include <MailTransport/TransportManager>
 #include <MailTransportAkonadi/MessageQueueJob>
-#include <identitymanager.h>
 
 #include "akonadicalendar_debug.h"
 #include <KMessageBox>
@@ -46,18 +46,14 @@ GroupwareUiDelegate::GroupwareUiDelegate(QObject *parent)
 {
 }
 
-GroupwareUiDelegate::~GroupwareUiDelegate()
-{
-}
+GroupwareUiDelegate::~GroupwareUiDelegate() = default;
 
 ITIPHandlerComponentFactory::ITIPHandlerComponentFactory(QObject *parent)
     : QObject(parent)
 {
 }
 
-ITIPHandlerComponentFactory::~ITIPHandlerComponentFactory()
-{
-}
+ITIPHandlerComponentFactory::~ITIPHandlerComponentFactory() = default;
 
 MailTransport::MessageQueueJob *ITIPHandlerComponentFactory::createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence,
                                                                                    const KIdentityManagement::Identity &identity,
